pub struct Fuse<B> {
inner: Option<B>,
}Expand description
A “fused” Body.
This Body yields Poll::Ready(None) forever after the underlying body yields
Poll::Ready(None), or an error Poll::Ready(Some(Err(_))), once.
Bodies should ideally continue to return Poll::Ready(None) indefinitely after the end of
the stream is reached. Fuse<B> avoids polling its underlying body B further after the
underlying stream as ended, which can be useful for implementation that cannot uphold this
guarantee.
This is akin to the functionality that std::iter::Iterator::fuse() provides for
Iterators.
Fields
inner: Option<B>Implementations